@@ -41,11 +41,11 @@ class Dict(dict):
             elif isinstance(arg, dict):
                 for key, val in arg.items():
                     self[key] = val
-            elif isinstance(arg, list) or isgenerator(arg):
+            elif isinstance(arg, tuple) and (not isinstance(arg[0], tuple)):
+                self[arg[0]] = arg[1]
+            elif isinstance(arg, (list, tuple)) or isgenerator(arg):
                 for key, val in arg:
                     self[key] = val
-            elif isinstance(arg, tuple):
-                self[arg[0]] = arg[1]
             else:
                 raise TypeError("Dict does not understand "
                                 "{0} types".format(type(arg)))
@@ -83,12 +83,7 @@ class Dict(dict):
         if isinstance(item, dict):
             return cls(item)
         elif isinstance(item, (list, tuple)):
-            new_iter = []
-            for elem in item:
-                new_iter.append(cls._hook(elem))
-            if isinstance(item, tuple):
-                new_iter = tuple(new_iter)
-            return new_iter
+            return type(item)(cls._hook(elem) for elem in item)
         return item
 
     def __getattr__(self, item):
@@ -191,10 +186,9 @@ class Dict(dict):
                 if item:
                     new_iter.append(item)
             elif isinstance(item, (list, tuple)):
-                new_item = cls._prune_iter(item, prune_zero, prune_empty_list)
+                new_item = type(item)(
+                    cls._prune_iter(item, prune_zero, prune_empty_list))
                 if new_item or not prune_empty_list:
-                    if isinstance(item, tuple):
-                        new_item = tuple(new_item)
                     new_iter.append(new_item)
             else:
                 new_iter.append(item)
@@ -207,17 +201,12 @@ class Dict(dict):
        """
        base = dict()
        for key, value in self.items():
-           if isinstance(value, self.__class__):
+           if isinstance(value, type(self)):
                base[key] = value.to_dict()
            elif isinstance(value, (list, tuple)):
-               base[key] = []
-               for item in value:
-                   if isinstance(item, self.__class__):
-                       base[key].append(item.to_dict())
-                   else:
-                       base[key].append(item)
-               if isinstance(value, tuple):
-                   base[key] = tuple(base[key])
+               base[key] = type(value)(
+                item.to_dict() if isinstance(item, type(self)) else 
+                item for item in value)
            else:
                base[key] = value
        return base
